# Copyright (c) 2020, NVIDIA CORPORATION.  All rights reserved.

"""Define a data structure containing information about a task class."""


class Task(object):
    """Define the task data structure."""

    def __init__(self, name, docker_image, docker_tag, docker_digest=None):
        """Initialize the task data structure.

        Args:
            name(str): Name of the task.
            docker_image(str): Name of the docker image to be mapped to.
            docker_digest(str): Digest value of the docker in the registry.
            docker_tag(str) (optional): Tag of the docker.

        """
        self.name = name
        self.docker_image = docker_image
        self.docker_tag = docker_tag
        self.docker_digest = docker_digest

    def get_config(self):
        """Return the Task configuration as a dict."""
        config = {
            "name": self.name,
            "docker_image": self.docker_image,
            "docker_tag": self.docker_tag,
            "docker_digest": self.docker_digest
        }
        return config

    @classmethod
    def from_config(cls, config_data):
        """Return a task data structure from config."""
        assert isinstance(config_data, dict), (
            "The config data should be a dictionary."
        )
        mandatory_args = ["name", "docker_image", "docker_tag"]
        optional_args = ["docker_digest"]
        assert all([key in mandatory_args for key in list(config_data.keys())])
        args = [
            config_data["name"],
            config_data["docker_image"],
            config_data["docker_tag"]
        ]
        kwargs = {}
        for arg in optional_args:
            if arg in config_data.keys():
                kwargs[arg] = config_data[arg]
        return Task(*args, **kwargs)
